AddressDTO class

A DTO for the address model.

This class provides a common structure for all address DTOs, including a title, name, surname, phone number, company name, tax number, tax office, country, state, city, district, neighborhood, street, building number, door number, zip code, latitude, longitude, and open address. It also provides methods to convert the DTO to and from a JSON object.

Inheritance

Constructors

AddressDTO({String? id, String? createdAt, String? updatedAt, bool? isActive, bool? isDeleted, String? title, String? name, String? surname, String? phoneNumber, String? companyName, String? taxNumber, String? taxOffice, String? country, String? state, String? city, String? district, String? neighborhood, String? street, String? buildingNo, String? doorNo, String? zipCode, double? latitude, double? longitude, String? openAddress})
AddressDTO.fromJson(Map<String, dynamic> json)

Properties

buildingNo String?
getter/setter pair
city String?
getter/setter pair
companyName String?
getter/setter pair
country String?
getter/setter pair
createdAt String?
The time when the DTO was created.
getter/setter pairinherited
district String?
getter/setter pair
doorNo String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The ID of the DTO.
getter/setter pairinherited
isActive bool?
Whether the DTO is active.
getter/setter pairinherited
isDeleted bool?
Whether the DTO has been deleted.
getter/setter pairinherited
latitude double?
getter/setter pair
longitude double?
getter/setter pair
name String?
getter/setter pair
neighborhood String?
getter/setter pair
openAddress String?
getter/setter pair
phoneNumber String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
getter/setter pair
street String?
getter/setter pair
surname String?
getter/setter pair
taxNumber String?
getter/setter pair
taxOffice String?
getter/setter pair
title String?
getter/setter pair
updatedAt String?
The time when the DTO was last updated.
getter/setter pairinherited
zipCode String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the BaseDTO to a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited