OrderItemDTO class

Inheritance

Constructors

OrderItemDTO({String? id, String? createdAt, String? updatedAt, bool? isActive, bool? isDeleted, String? status, int? quantity, String? startDate, String? endDate, double? basePrice, double? discountedPrice, double? paidPrice, double? taxPercentage, double? taxAmount, String? currency, String? customerNote, String? storeNote, CampaignDTO? campaign, ProductDetail? productDetail, List<RefundDTO>? refunds, List<ProductDTO>? sides, StoreDTO? store, String? fromCurrency, double? currencyRate, String? baseCurrency, double? baseCurrencyRate, List<StockDTO>? stocks})
OrderItemDTO.fromJson(Map<String, dynamic> json)

Properties

baseCurrency String?
getter/setter pair
baseCurrencyRate double?
getter/setter pair
basePrice double?
getter/setter pair
campaign CampaignDTO?
getter/setter pair
createdAt String?
The time when the DTO was created.
getter/setter pairinherited
currency String?
getter/setter pair
currencyRate double?
getter/setter pair
customerNote String?
getter/setter pair
discountedPrice double?
getter/setter pair
endDate String?
getter/setter pair
fromCurrency String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The ID of the DTO.
getter/setter pairinherited
isActive bool?
Whether the DTO is active.
getter/setter pairinherited
isDeleted bool?
Whether the DTO has been deleted.
getter/setter pairinherited
paidPrice double?
getter/setter pair
productDetail ProductDetail?
getter/setter pair
quantity int?
getter/setter pair
refunds List<RefundDTO>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sides List<ProductDTO>?
getter/setter pair
startDate String?
getter/setter pair
status String?
getter/setter pair
stocks List<StockDTO>?
getter/setter pair
store StoreDTO?
getter/setter pair
storeNote String?
getter/setter pair
taxAmount double?
getter/setter pair
taxPercentage double?
getter/setter pair
updatedAt String?
The time when the DTO was last updated.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the BaseDTO to a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited