RefundDTO class

Inheritance

Constructors

RefundDTO({String? id, String? createdAt, String? updatedAt, bool? isActive, bool? isDeleted, String? sku, int? quantity, String? type, String? status, bool? include, String? note, String? startDate, String? endDate, String? purchaseDate, double? purchasePrice, String? purchaseCurrency})
RefundDTO.fromJson(Map<String, dynamic> json)

Properties

createdAt String?
The time when the DTO was created.
getter/setter pairinherited
endDate String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The ID of the DTO.
getter/setter pairinherited
include bool?
getter/setter pair
isActive bool?
Whether the DTO is active.
getter/setter pairinherited
isDeleted bool?
Whether the DTO has been deleted.
getter/setter pairinherited
note String?
getter/setter pair
purchaseCurrency String?
getter/setter pair
purchaseDate String?
getter/setter pair
purchasePrice double?
getter/setter pair
quantity int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sku String?
getter/setter pair
startDate String?
getter/setter pair
status String?
getter/setter pair
type String?
getter/setter pair
updatedAt String?
The time when the DTO was last updated.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the BaseDTO to a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited