PriceDTO class

A DTO for the price model.

This class provides a common structure for all price DTOs, including an amount, discounted amount, currency, symbol, tax amount, tax percentage, store ID, from currency, currency rate, base currency, base currency rate, and discounted tax amount. It also provides methods to convert the DTO to and from a JSON object.

Inheritance

Constructors

PriceDTO({String? id, String? createdAt, String? updatedAt, bool? isActive, bool? isDeleted, double? amount, double? discountedAmount, String? currency, String? symbol, double? taxAmount, double? taxPercentage, String? storeId, String? fromCurrency, double? currencyRate, String? baseCurrency, double? baseCurrencyRate, double? discountedTaxAmount, double? payAmount})
PriceDTO.fromJson(Map<String, dynamic> json)

Properties

amount double?
getter/setter pair
baseCurrency String?
getter/setter pair
baseCurrencyRate double?
getter/setter pair
createdAt String?
The time when the DTO was created.
getter/setter pairinherited
currency String?
getter/setter pair
currencyRate double?
getter/setter pair
discountedAmount double?
getter/setter pair
discountedTaxAmount double?
getter/setter pair
fromCurrency String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The ID of the DTO.
getter/setter pairinherited
isActive bool?
Whether the DTO is active.
getter/setter pairinherited
isDeleted bool?
Whether the DTO has been deleted.
getter/setter pairinherited
payAmount double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String?
getter/setter pair
symbol String?
getter/setter pair
taxAmount double?
getter/setter pair
taxPercentage double?
getter/setter pair
updatedAt String?
The time when the DTO was last updated.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the BaseDTO to a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited