StoreDTO class
A DTO for the store model.
This class provides a common structure for all store DTOs, including a type, info, children, and setting. It also provides methods to convert the DTO to and from a JSON object.
Constructors
Properties
- averageRating ↔ double?
-
getter/setter pair
-
children
↔ List<
StoreDTO> ? -
getter/setter pair
- createdAt ↔ String?
-
The time when the DTO was created.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlighted ↔ bool?
-
getter/setter pair
- id ↔ String?
-
The ID of the DTO.
getter/setter pairinherited
- info ↔ StoreInfoDTO?
-
getter/setter pair
- isActive ↔ bool?
-
Whether the DTO is active.
getter/setter pairinherited
- isDeleted ↔ bool?
-
Whether the DTO has been deleted.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setting ↔ SettingDTO?
-
getter/setter pair
- totalRatingCount ↔ double?
-
getter/setter pair
- type ↔ StoreType?
-
getter/setter pair
- updatedAt ↔ String?
-
The time when the DTO was last updated.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the BaseDTO to a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited