SuggestionDTO class
A DTO for the suggestion model.
This class provides a common structure for all suggestion DTOs, including a name, surname, phone number, email, subject, message, store, user, and solved. It also provides methods to convert the DTO to and from a JSON object.
Constructors
Properties
- createdAt ↔ String?
-
The time when the DTO was created.
getter/setter pairinherited
- email ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID of the DTO.
getter/setter pairinherited
- isActive ↔ bool?
-
Whether the DTO is active.
getter/setter pairinherited
- isDeleted ↔ bool?
-
Whether the DTO has been deleted.
getter/setter pairinherited
- message ↔ String?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- phoneNumber ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- solved ↔ bool?
-
getter/setter pair
- store ↔ StoreDTO?
-
getter/setter pair
- subject ↔ String?
-
getter/setter pair
- surname ↔ String?
-
getter/setter pair
- updatedAt ↔ String?
-
The time when the DTO was last updated.
getter/setter pairinherited
- user ↔ UserDTO?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the BaseDTO to a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited