AuthRepository class

A repository for the auth model.

This class provides methods to interact with the API endpoints for the auth model. It also provides methods to convert the JSON object received from the API to a ResponseItemDTO or ResponseListDTO of AuthDTO. Methods:

Constructors

AuthRepository(ParodiaHTTP http)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkResetPasswordCode({ResetPasswordBodyDataModel? data}) Future<ResponseItemDTO>
guestRegister() Future<ResponseItemDTO>
login({AuthAndProfileBodyDataModel? data}) Future<ResponseItemDTO>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({AuthAndProfileBodyDataModel? data}) Future<ResponseItemDTO>
resetPassword({ResetPasswordBodyDataModel? data}) Future<ResponseItemDTO>
sendResetPasswordCode({ResetPasswordBodyDataModel? data}) Future<ResponseItemDTO>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited