CurrencyRepository class

A repository for the currency model.

This class provides methods to interact with the API endpoints for the currency model. It also provides methods to convert the JSON object received from the API to a ResponseItemDTO or ResponseListDTO of CurrencyDTO. Methods:

Constructors

CurrencyRepository(ParodiaHTTP http)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrencies() Future<ResponseItemDTO<List<String>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited