OrderRepository class

A repository for the order model.

This class provides methods to interact with the API endpoints for the order model. It also provides methods to convert the JSON object received from the API to a ResponseItemDTO or ResponseListDTO of OrderDTO. Methods:

Constructors

OrderRepository(ParodiaHTTP http)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createOrder({OrderBodyDataModel? data}) Future<ResponseItemDTO<OrderDTO>>
getAll({OrderQueryModel? query}) Future<ResponseListDTO<OrderDTO>>
getById({String? id}) Future<ResponseItemDTO<OrderDTO>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refundOrder({RefundOrderBodyDataModel? data, String? id}) Future<ResponseItemDTO>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited