ProfileDTO class
A DTO for the profile model.
Constructors
- ProfileDTO({String? id, String? createdAt, String? updatedAt, bool? isActive, bool? isDeleted, String? name, String? surname, bool? isVerified, String? phoneNumber, String? birthday, String? gender, String? companyName, String? taxOffice, String? taxNumber, String? fullName, UserDTO? user, String? socialSecurityNo, PhotoDTO? photo})
-
ProfileDTO.fromJson(Map<
String, dynamic> json)
Properties
- birthday ↔ String?
-
getter/setter pair
- companyName ↔ String?
-
getter/setter pair
- createdAt ↔ String?
-
The time when the DTO was created.
getter/setter pairinherited
- fullName ↔ String?
-
getter/setter pair
- gender ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID of the DTO.
getter/setter pairinherited
- isActive ↔ bool?
-
Whether the DTO is active.
getter/setter pairinherited
- isDeleted ↔ bool?
-
Whether the DTO has been deleted.
getter/setter pairinherited
- isVerified ↔ bool?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- phoneNumber ↔ String?
-
getter/setter pair
- photo ↔ PhotoDTO?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
getter/setter pair
- surname ↔ String?
-
getter/setter pair
- taxNumber ↔ String?
-
getter/setter pair
- taxOffice ↔ String?
-
getter/setter pair
- updatedAt ↔ String?
-
The time when the DTO was last updated.
getter/setter pairinherited
- user ↔ UserDTO?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the BaseDTO to a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited