FeatureRepository class
A repository for the feature model.
This class provides methods to interact with the API endpoints for the feature model. It also provides methods to convert the JSON object received from the API to a ResponseItemDTO or ResponseListDTO of FeatureDTO. Methods:
Constructors
- FeatureRepository(ParodiaHTTP http)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAll(
) → Future< ResponseListDTO< FeatureDTO> > -
getBySlug(
{String? slug, StoreIdQueryModel? query}) → Future< ResponseItemDTO< FeatureDTO> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited